@@ -1,23 +1,13 @@
 from qtpy import QtWidgets
-from qtpy.QtCore import Signal, QThread
+
 from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo, DataFromPlugins
 import numpy as np
-from pymodaq.daq_viewer.utility_classes import DAQ_Viewer_base
-from easydict import EasyDict as edict
-from collections import OrderedDict
-from pymodaq.daq_utils.daq_utils import gauss1D
-from pymodaq.daq_viewer.utility_classes import comon_parameters
+from pymodaq.control_modules.viewer_utility_classes import DAQ_Viewer_base, comon_parameters, main
+
+from pymodaq.daq_utils.math_utils import gauss1D
 
 
 class DAQ_0DViewer_Mock(DAQ_Viewer_base):
-    """
-        =============== =================
-        **Attributes**  **Type**
-        *params*        dictionnary list
-        *x_axis*        1D numpy array
-        *ind_data*      int
-        =============== =================
-    """
     params = comon_parameters + [
         {'title': 'Wait time (ms)', 'name': 'wait_time', 'type': 'int', 'value': 100, 'default': 100, 'min': 0},
         {'title': 'Separated viewers', 'name': 'sep_viewers', 'type': 'bool', 'value': False},
@@ -39,9 +29,8 @@ class DAQ_0DViewer_Mock(DAQ_Viewer_base):
             {'title': 'amp_noise', 'name': 'amp_noise', 'type': 'float', 'value': 0.1, 'default': 0.1, 'min': 0}
         ]}]
 
-    def __init__(self, parent=None,
-                 params_state=None):  # init_params is a list of tuple where each tuple contains info on a 1D channel (Ntps,amplitude, width, position and noise)
-        super(DAQ_0DViewer_Mock, self).__init__(parent, params_state)
+    def ini_attributes(self):
+        self.controller: str = None
         self.x_axis = None
         self.ind_data = 0
         self.lcd_init = False
@@ -71,46 +60,43 @@ class DAQ_0DViewer_Mock(DAQ_Viewer_base):
         self.data_mock = []
         for param in self.settings.children():
             if 'Mock' in param.name():
-                x = np.linspace(0, param.children()[0].value() - 1, param.children()[0].value())
+                x = np.linspace(0, param['Npts'] - 1, param['Npts'])
                 self.data_mock.append(
-                    param.children()[1].value() * gauss1D(
-                        x, param.children()[2].value(), param.children()[3].value(),
-                        param.children()[4].value()) + param.children()[5].value() * np.random.rand(
-                        (param.children()[0].value())))
+                    param['Amp'] * gauss1D(x,
+                                                          param['x0'],
+                                                          param['dx'],
+                                                          param['n']) + \
+                    param['amp_noise'] * np.random.rand((param['Npts'] )))
 
     def ini_detector(self, controller=None):
+        """Detector communication initialization
+
+        Parameters
+        ----------
+        controller: (object)
+            custom object of a PyMoDAQ plugin (Slave case). None if only one actuator/detector by controller
+            (Master case)
+
+        Returns
+        -------
+        info: str
+        initialized: bool
+            False if initialization failed otherwise True
         """
-            Initialisation procedure of the detector.
+        self.ini_detector_init(old_controller=controller,
+                               new_controller='Mock controller')
 
-            Returns
-            -------
-            ???
-                the initialized status.
-
-            See Also
-            --------
-            set_Mock_data
-        """
-
-        self.status.update(edict(initialized=False, info="", x_axis=None, y_axis=None, controller=None))
-        if self.settings.child(('controller_status')).value() == "Slave":
-            if controller is None:
-                raise Exception('no controller has been defined externally while this detector is a slave one')
-            else:
-                self.controller = controller
-        else:
-            self.controller = "Mock controller"
         self.set_Mock_data()
         self.emit_status(ThreadCommand('update_main_settings', [['wait_time'],
-                                                                self.settings.child(('wait_time')).value(), 'value']))
+                                                                self.settings.child('wait_time').value(), 'value']))
 
         # initialize viewers with the future type of data
         self.data_grabed_signal.emit(
             [DataFromPlugins(name='Mock1', data=[np.array(0)], dim='Data0D', labels=['Mock1', 'label2'])])
 
-        self.status.initialized = True
-        self.status.controller = self.controller
-        return self.status
+        initialized = True
+        info = 'RAS'
+        return info, initialized
 
     def close(self):
         """
@@ -166,3 +152,6 @@ class DAQ_0DViewer_Mock(DAQ_Viewer_base):
         """
 
         return ""
+
+if __name__ == '__main__':
+    main(__file__)
\ No newline at end of file
