@@ -1,12 +1,12 @@
-from qtpy.QtCore import QThread
+from qtpy.QtCore import QThread, Slot, QRectF
 from qtpy import QtWidgets
 import numpy as np
-import pymodaq.daq_utils.daq_utils as mylib
-from pymodaq.daq_viewer.utility_classes import DAQ_Viewer_base
+import pymodaq.daq_utils.math_utils as mutils
+from pymodaq.control_modules.viewer_utility_classes import DAQ_Viewer_base, main, comon_parameters
 from easydict import EasyDict as edict
 from collections import OrderedDict
 from pymodaq.daq_utils.daq_utils import ThreadCommand, getLineInfo, DataFromPlugins, Axis
-from pymodaq.daq_viewer.utility_classes import comon_parameters
+from pymodaq.daq_utils.array_manipulation import crop_array_to_axis, crop_vector_to_axis
 
 
 class DAQ_2DViewer_Mock(DAQ_Viewer_base):
@@ -27,6 +27,7 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
         {'title': 'Nimages colors:', 'name': 'Nimagescolor', 'type': 'int', 'value': 1, 'default': 1, 'min': 0,
          'max': 3},
         {'title': 'Nimages pannels:', 'name': 'Nimagespannel', 'type': 'int', 'value': 1, 'default': 0, 'min': 0},
+        {'title': 'Use ROISelect', 'name': 'use_roi_select', 'type': 'bool', 'value': False},
         {'title': 'Threshold', 'name': 'threshold', 'type': 'int', 'value': 1, 'min': 0},
         {'title': 'rolling', 'name': 'rolling', 'type': 'int', 'value': 1, 'min': 0},
         {'title': 'Nx', 'name': 'Nx', 'type': 'int', 'value': 100, 'default': 100, 'min': 1},
@@ -38,19 +39,27 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
         {'title': 'dy', 'name': 'dy', 'type': 'float', 'value': 40, 'default': 40, 'min': 1},
         {'title': 'n', 'name': 'n', 'type': 'int', 'value': 1, 'default': 1, 'min': 1},
         {'title': 'amp_noise', 'name': 'amp_noise', 'type': 'float', 'value': 4, 'default': 0.1, 'min': 0},
+
         {'title': 'Cam. Prop.:', 'name': 'cam_settings', 'type': 'group', 'children': []},
     ]
 
-    def __init__(self, parent=None,
-                 params_state=None):  # init_params is a list of tuple where each tuple contains info on a 1D channel (Ntps,amplitude, width, position and noise)
-        super(DAQ_2DViewer_Mock, self).__init__(parent, params_state)
+    def ini_attributes(self):
+        self.controller: str = None
+
         self.x_axis = None
         self.y_axis = None
         self.live = False
         self.ind_commit = 0
         self.ind_data = 0
+        self._ROI = dict(position=[10, 10], size=[5, 5])
 
-    def commit_settings(self, param):
+    @Slot(QRectF)
+    def ROISelect(self, roi_pos_size: QRectF):
+        self._ROI['position'] = int(roi_pos_size.left()), int(roi_pos_size.top())
+        self._ROI['size'] = int(roi_pos_size.width()), int(roi_pos_size.height())
+
+    def commit_settings(self
+                        , param):
         """
             Activate parameters changes on the hardware.
 
@@ -83,50 +92,35 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
             -------
                 The computed data mock.
         """
+        x_axis = np.linspace(0, self.settings.child('Nx').value(), self.settings.child('Nx').value(),
+                             endpoint=False)
+        y_axis = np.linspace(0, self.settings.child('Ny').value(), self.settings.child('Ny').value(),
+                             endpoint=False)
+        data_mock = self.settings.child('Amp').value() * (
+            mutils.gauss2D(x_axis, self.settings.child('x0').value(), self.settings.child('dx').value(),
+                          y_axis, self.settings.child('y0').value(), self.settings.child('dy').value(),
+                          self.settings.child('n').value())) + self.settings.child('amp_noise').value() * \
+                    np.random.rand(len(y_axis), len(x_axis))
 
-        if self.settings.child('ROIselect', 'use_ROI').value():
-            x_axis = np.linspace(self.settings.child('ROIselect', 'x0').value(),
-                                 self.settings.child('ROIselect', 'x0').value() + self.settings.child('ROIselect',
-                                                                                                      'width').value(),
-                                 self.settings.child('ROIselect', 'width').value(), endpoint=False)
-            y_axis = np.linspace(self.settings.child('ROIselect', 'y0').value(),
-                                 self.settings.child('ROIselect', 'y0').value() + self.settings.child('ROIselect',
-                                                                                                      'height').value(),
-                                 self.settings.child('ROIselect', 'height').value(), endpoint=False)
-            data_mock = self.settings.child(('Amp')).value() * (
-                mylib.gauss2D(x_axis, self.settings.child(('x0')).value(), self.settings.child(('dx')).value(),
-                              y_axis, self.settings.child(('y0')).value(), self.settings.child(('dy')).value(),
-                              self.settings.child(('n')).value())) + self.settings.child(
-                ('amp_noise')).value() * np.random.rand(len(y_axis), len(x_axis))
+        for indy in range(data_mock.shape[0]):
+            data_mock[indy, :] = data_mock[indy, :] * np.sin(x_axis / 4) ** 2
+        data_mock = np.roll(data_mock, self.ind_data * self.settings.child('rolling').value(), axis=1)
+
+        if self.settings['use_roi_select']:
+            x_axis, y_axis, data = \
+                crop_array_to_axis(x_axis, y_axis, data_mock,
+                                   (self._ROI['position'][0], self._ROI['position'][0] + self._ROI['size'][0],
+                                    self._ROI['position'][1], self._ROI['position'][1] + self._ROI['size'][1]))
 
-            for indy in range(data_mock.shape[0]):
-                data_mock[indy, :] = data_mock[indy, :] * np.sin(x_axis / 8) ** 2
-            data_mock = np.roll(data_mock, self.ind_data * self.settings.child(('rolling')).value(), axis=1)
 
             try:
-                self.image[self.settings.child('ROIselect', 'y0').value():
-                           self.settings.child('ROIselect', 'y0').value() + self.settings.child(
-                    'ROIselect', 'height').value(),
-                    self.settings.child('ROIselect', 'x0').value():
-                    self.settings.child('ROIselect', 'x0').value() + self.settings.child('ROIselect', 'width').value()
-                ] = data_mock
+                self.image[self._ROI['position'][1]:self._ROI['position'][1] + self._ROI['size'][1]+1,
+                     self._ROI['position'][0]:self._ROI['position'][0] + self._ROI['size'][0]+1] = data
 
             except Exception as e:
                 self.emit_status(ThreadCommand('Update_Status', [getLineInfo() + str(e), 'log']))
         else:
-            x_axis = np.linspace(0, self.settings.child(('Nx')).value(), self.settings.child(('Nx')).value(),
-                                 endpoint=False)
-            y_axis = np.linspace(0, self.settings.child(('Ny')).value(), self.settings.child(('Ny')).value(),
-                                 endpoint=False)
-            data_mock = self.settings.child(('Amp')).value() * (
-                mylib.gauss2D(x_axis, self.settings.child(('x0')).value(), self.settings.child(('dx')).value(),
-                              y_axis, self.settings.child(('y0')).value(), self.settings.child(('dy')).value(),
-                              self.settings.child(('n')).value())) + self.settings.child(
-                ('amp_noise')).value() * np.random.rand(len(y_axis), len(x_axis))
 
-            for indy in range(data_mock.shape[0]):
-                data_mock[indy, :] = data_mock[indy, :] * np.sin(x_axis / 4) ** 2
-            data_mock = np.roll(data_mock, self.ind_data * self.settings.child(('rolling')).value(), axis=1)
             self.image = data_mock
 
         self.ind_data += 1
@@ -136,42 +130,18 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
         return self.image
 
     def ini_detector(self, controller=None):
-        """
-            Initialisation procedure of the detector initializing the status dictionnary.
+        self.ini_detector_init(controller, "Mock controller")
 
-            See Also
-            --------
-            daq_utils.ThreadCommand, get_xaxis, get_yaxis
-        """
-        self.status.update(edict(initialized=False, info="", x_axis=None, y_axis=None, controller=None))
-        try:
+        self.x_axis = self.get_xaxis()
+        self.y_axis = self.get_yaxis()
 
-            if self.settings.child(('controller_status')).value() == "Slave":
-                if controller is None:
-                    raise Exception('no controller has been defined externally while this detector is a slave one')
-                else:
-                    self.controller = controller
-            else:
-                self.controller = "Mock controller"
+        # initialize viewers with the future type of data but with 0value data
+        self.data_grabed_signal_temp.emit(self.average_data(1, True))
+        # OrderedDict(name='Mock3', data=[np.zeros((128,))], type='Data1D')])
 
-            self.x_axis = self.get_xaxis()
-            self.y_axis = self.get_yaxis()
-
-            # initialize viewers with the future type of data but with 0value data
-            self.data_grabed_signal_temp.emit(self.average_data(1, True))
-            # OrderedDict(name='Mock3', data=[np.zeros((128,))], type='Data1D')])
-
-            self.status.x_axis = self.x_axis
-            self.status.y_axis = self.y_axis
-            self.status.initialized = True
-            self.status.controller = self.controller
-            return self.status
-
-        except Exception as e:
-            self.emit_status(ThreadCommand('Update_Status', [getLineInfo() + str(e), 'log']))
-            self.status.info = getLineInfo() + str(e)
-            self.status.initialized = False
-            return self.status
+        initialized = True
+        info = 'Init'
+        return info, initialized
 
     def close(self):
         """
@@ -180,34 +150,10 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
         pass
 
     def get_xaxis(self):
-        """
-            Get the current x_axis from the Mock data setting.
-
-            Returns
-            -------
-            1D numpy array
-                the current x_axis.
-
-            See Also
-            --------
-            set_Mock_data
-        """
         self.set_Mock_data()
         return self.x_axis
 
     def get_yaxis(self):
-        """
-            Get the current y_axis from the Mock data setting.
-
-            Returns
-            -------
-            1D numpy array
-                the current y_axis.
-
-            See Also
-            --------
-            set_Mock_data
-        """
         self.set_Mock_data()
         return self.y_axis
 
@@ -251,10 +197,10 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
             data_tmp += self.set_Mock_data()
         data_tmp = data_tmp / Naverage
 
-        data_tmp = data_tmp * (data_tmp >= self.settings.child('threshold').value()) * (init is False)
-        for ind in range(self.settings.child(('Nimagespannel')).value()):
+        data_tmp = data_tmp * (data_tmp >= self.settings['threshold']) * (init is False)
+        for ind in range(self.settings['Nimagespannel']):
             datatmptmp = []
-            for indbis in range(self.settings.child(('Nimagescolor')).value()):
+            for indbis in range(self.settings['Nimagescolor']):
                 datatmptmp.append(data_tmp)
             data.append(DataFromPlugins(name='Mock2D_{:d}'.format(ind), data=datatmptmp, dim='Data2D'))
         # data.append(OrderedDict(name='Mock2D_1D',data=[np.mean(data_tmp,axis=0)], type='Data1D'))
@@ -266,3 +212,7 @@ class DAQ_2DViewer_Mock(DAQ_Viewer_base):
         """
         self.live = False
         return ""
+
+
+if __name__ == '__main__':
+    main(__file__)
