@@ -4,6 +4,8 @@ Demo Wrapper to illustrate the plugin developpement. This Mock wrapper will emul
 
 from time import perf_counter, sleep
 import math
+from numpy import random
+
 
 class ActuatorWrapper:
     units = 'mm'
@@ -50,14 +52,15 @@ class ActuatorWrapper:
 
 class ActuatorWrapperWithTau(ActuatorWrapper):
 
-    units = '°K'
+    units = '°'
 
     def __init__(self):
         super().__init__()
         self._espilon = 1e-2
         self._tau = 3  # s
         self._alpha = None
-        self._init_value = None
+        self._init_value = 0.
+        self._current_value = 0.
         self._start_time = 0
         self._moving = False
 
@@ -69,7 +72,6 @@ class ActuatorWrapperWithTau(ActuatorWrapper):
     def epsilon(self, eps):
         self._espilon = eps
 
-
     @property
     def is_moving(self):
         return self._moving
@@ -98,7 +100,6 @@ class ActuatorWrapperWithTau(ActuatorWrapper):
         else:
             self._tau = value
 
-
     def move_at(self, value):
         """
         Send a call to the actuator to move at the given value
@@ -131,6 +132,9 @@ class ActuatorWrapperWithTau(ActuatorWrapper):
                 math.exp(- self._alpha * (curr_time-self._start_time) / self._tau) *\
                 (self._init_value - self._target_value) + self._target_value
 
+        self._current_value += (random.random() - 0.5) * self.epsilon / 10
+        # add some small random value to get fluctuations in positions
+
         return self._current_value
 
 
